summaryrefslogtreecommitdiff
path: root/solenv
diff options
context:
space:
mode:
authorJens-Heiner Rechtien <hr@openoffice.org>2006-04-19 14:04:49 +0000
committerJens-Heiner Rechtien <hr@openoffice.org>2006-04-19 14:04:49 +0000
commit9ccf695edce27b9a6affa92b79c242024f0f2b94 (patch)
tree4401f0b37c0c106ccfb4a79e74130cb92ad01f2f /solenv
parent08a6d3d23eb59ea5918ee0e8e63ef5480439912b (diff)
INTEGRATION: CWS native43 (1.48.74); FILE MERGED
2006/04/07 10:27:00 is 1.48.74.2: #6402412# content for Solaris patchinfo file 2006/04/06 08:38:13 is 1.48.74.1: #b6402412# changing architecture string for x86
Diffstat (limited to 'solenv')
-rw-r--r--solenv/bin/modules/installer/epmfile.pm18
1 files changed, 12 insertions, 6 deletions
diff --git a/solenv/bin/modules/installer/epmfile.pm b/solenv/bin/modules/installer/epmfile.pm
index d1e38b75ae8d..e54c84d4eb0c 100644
--- a/solenv/bin/modules/installer/epmfile.pm
+++ b/solenv/bin/modules/installer/epmfile.pm
@@ -4,9 +4,9 @@
#
# $RCSfile: epmfile.pm,v $
#
-# $Revision: 1.48 $
+# $Revision: 1.49 $
#
-# last change: $Author: kz $ $Date: 2006-01-31 18:23:54 $
+# last change: $Author: hr $ $Date: 2006-04-19 15:04:49 $
#
# The Contents of this file are made available subject to
# the terms of GNU Lesser General Public License Version 2.1.
@@ -2197,17 +2197,23 @@ sub replace_one_variable_in_file
sub set_patchinfo
{
- my ( $patchinfofile, $patchid ) = @_;
+ my ( $patchinfofile, $patchid, $allvariables ) = @_;
- # Setting: PATCHIDPLACEHOLDER and ARCHITECTUREPLACEHOLDER
+ # Setting: PATCHIDPLACEHOLDER and ARCHITECTUREPLACEHOLDER and PATCHCORRECTSPLACEHOLDER
replace_one_variable_in_file($patchinfofile, "PATCHIDPLACEHOLDER", $patchid);
my $architecture = "";
if ( $installer::globals::issolarissparcbuild ) { $architecture = "sparc"; }
- if ( $installer::globals::issolarisx86build ) { $architecture = "x86"; }
+ if ( $installer::globals::issolarisx86build ) { $architecture = "i386"; }
replace_one_variable_in_file($patchinfofile, "ARCHITECTUREPLACEHOLDER", $architecture);
+
+ if ( ! $allvariables->{'SOLARISPATCHCORRECTS'} ) { installer::exiter::exit_program("ERROR: No setting for PATCH_CORRECTS in zip list file!", "set_patchinfo"); }
+ my $patchcorrects = $allvariables->{'SOLARISPATCHCORRECTS'};
+
+ replace_one_variable_in_file($patchinfofile, "PATCHCORRECTSPLACEHOLDER", $patchcorrects);
+
}
######################################################
@@ -2244,7 +2250,7 @@ sub finalize_patch
my $patchinfofilename = $patchid . $installer::globals::separator . "patchinfo";
my $patchinfofile = installer::files::read_file($patchinfofilename);
- set_patchinfo($patchinfofile, $patchid);
+ set_patchinfo($patchinfofile, $patchid, $allvariables);
installer::files::save_file($patchinfofilename, $patchinfofile);
}